@@ -317,6 +317,11 @@ class EducPlanPos(Base):
     cycle_id = Column(ForeignKey('univer_cycles.cycle_id'))
     cycle = relationship('Cycle')
 
+    # Цикловой компонент
+    cycle_component_id = Column(ForeignKey(
+        'univer_cycle_component.cycle_component_id'))
+    cycle_component = relationship('CycleComponent')
+
     # Количество часов
     hours = Column('educ_plan_pos_hours', Integer)
 
@@ -356,6 +361,33 @@ class Cycle(Base):
         return self.name_ru
 
 
+class CycleComponent(Base):
+    """
+    Цикловой компонент
+    """
+    __tablename__ = 'univer_cycle_component'
+
+    # Идентификатор
+    id = Column('cycle_component_id', Integer, primary_key=True)
+
+    # Статус
+    status = Column(Integer)
+
+    # Наименование
+    name_ru = Column('cycle_component_name_ru', String)
+    name_kz = Column('cycle_component_name_kz', String)
+    name_en = Column('cycle_component_name_en', String)
+    short_name_ru = Column('cycle_component_short_name_ru', String)
+    short_name_kz = Column('cycle_component_short_name_ru', String)
+    short_name_en = Column('cycle_component_short_name_ru', String)
+
+    def __repr__(self):
+        return f'<CycleComponent {self} (id={self.id} status={self.status})>'
+
+    def __str__(self):
+        return self.name_ru
+
+
 class Attendance(Base):
     """
     Журнал посещений и успеваемости
@@ -1033,7 +1065,7 @@ class EducPlanPosGroup(Base):
     educ_plan = relationship('EducPlan')
 
     # Семестр позиции учебного плана
-    educ_plan_pos_semester = Column(Integer)
+    educ_plan_pos_semester = Column('educ_plan_pos_semestr', Integer)
 
     # Наименование
     name_ru = Column('pos_group_name_ru', String)
